==> haskell-persistent-sqlite-2.13.1.1-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   persistent-sqlite
version:                2.13.1.1
visibility:             public
id:                     persistent-sqlite-2.13.1.1-IOXCibP8D2UFFlt4JZeTGT
key:                    persistent-sqlite-2.13.1.1-IOXCibP8D2UFFlt4JZeTGT
license:                MIT
maintainer:             Michael Snoyman <michael@snoyman.com>
author:                 Michael Snoyman <michael@snoyman.com>
stability:              Stable
homepage:               http://www.yesodweb.com/book/persistent
synopsis:               Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:               Database, Yesod
abi:                    8bd3c8aa3df1ae1a1f978339c710dc8b
exposed:                True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:            /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
library-dirs:           /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-persistent-sqlite
hs-libraries:           HSpersistent-sqlite-2.13.1.1-IOXCibP8D2UFFlt4JZeTGT
extra-libraries:        pthread sqlite3
extra-libraries-static: sqlite3 m z
depends:
    aeson-2.1.2.1-7cfkxE9Bq2x7khGuVuQDC7 base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-RIPQH88pa6HdGnxqZVAxX
    containers-0.6.7 microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    monad-logger-0.3.42-1kqzFCyaEcMHCgtk5b9Nkn mtl-2.2.2
    persistent-2.14.5.2-HNzc5acoInpLmHTOaUzW0e
    resource-pool-0.2.3.2-5bcWnmXNcCc8hb8kyyyxv1
    resourcet-1.2.6-85GJIioYIs529GIVOhD7J4 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-7E9U8fDCyyE7V5F5vC663n

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:           /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.13.1.1-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   persistent-sqlite
version:                2.13.1.1
visibility:             public
id:                     persistent-sqlite-2.13.1.1-EigEhXYhX8u8wxI9JxEpfb
key:                    persistent-sqlite-2.13.1.1-EigEhXYhX8u8wxI9JxEpfb
license:                MIT
maintainer:             Michael Snoyman <michael@snoyman.com>
author:                 Michael Snoyman <michael@snoyman.com>
stability:              Stable
homepage:               http://www.yesodweb.com/book/persistent
synopsis:               Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:               Database, Yesod
abi:                    1f2bd1e54962cc7b7d53ac154e0e8cc1
exposed:                True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:            /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
library-dirs:           /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/persistent-sqlite-2.13.1.1
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-persistent-sqlite
hs-libraries:           HSpersistent-sqlite-2.13.1.1-EigEhXYhX8u8wxI9JxEpfb
extra-libraries:        pthread sqlite3
extra-libraries-static: sqlite3 m z
depends:
    aeson-2.1.2.1-7VTFzNaeQhH4xougawMBap base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-793fWFbadkvFwVYySs1ukE
    containers-0.6.7 microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    monad-logger-0.3.42-4B1ByNIpC5oKegCVUk6uRM mtl-2.2.2
    persistent-2.14.5.2-2baaq0U3ooO1367vv6KzHR
    resource-pool-0.2.3.2-BxDvxmo4sDl6W5uOYQs4yN
    resourcet-1.2.6-6Q9ZdpuTS1aCzu997x6CHk text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-Iia3zhz8DVL3Efh3E6ja96

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:           /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
